
//+----------------------------------------------------------------------------
//
//  Function:       cancelSelectStart
//
//  Description:    Cancels the onselectstart event to prevent user from
//                  selecting text in the slider.
//
//  Arguments:      none
//
//  Returns:        false (returnValue)
//
//+----------------------------------------------------------------------------

function cancelSelectStart()
{
    window.event.returnValue = false;
    window.event.cancelBubble = true;

    return false;
}

function cancelClick()
{
	window.event.returnValue = true;
	window.event.cancelBubble = true;

	return true;
}


function math_round(value, fraction)
{
	var s = String(value);

	if ((i = s.indexOf('.')) != -1) {
		s = s.substring(0, i + fraction + 1);

	}

	return Number(s);
}


function smil_parseTimingSpecifiers(spec)
{
	var arr;
	var v = spec.replace(/\s/g, ''); // normalization

	var t = null;

	switch (v.charAt(0)) {
	case '0' :
	case '1' :
	case '2' :
	case '3' :
	case '4' :
	case '5' :
	case '6' :
	case '7' :
	case '8' :
	case '9' :
	case '-' :
	case '+' :
		// offset value
		t = smil_parseClockSpecifiers(v);

		break;

	default:
		if (v.indexOf('wallclock') == 0) {
			// wallclock-sync-value

		} else if (v.indexOf('indefinite') == 0) {
			// indefinite
		} else {
			arr = v.split(/-|\+/, 3);
			var symbol = arr[0];
			var time = arr[1];

			if (symbol.indexOf('.') == -1) {
				// event-value with an unspecified (i.e. default) eventbase-element
			} else if (
				(symbol.substring(symbol.length - '.begin'.length) == '.begin') ||
				(symbol.substring(symbol.length - '.end'.length) == '.end')
			) {
				// syncbase-value
				t = smil_parseClockSpecifiers(time);
			} else if (symbol.indexOf('.marker(') != -1) {
				// media-marker-value
			} else {
				// event-value (with a specified eventbase-element)
			}
		}
	}


	return t;
}

function smil_parseClockSpecifiers(value)
{

/*	Clock-value         ::= ( Full-clock-value | Partial-clock-value | Timecount-value )
	Full-clock-value    ::= Hours ":" Minutes ":" Seconds ("." Fraction)?
	Partial-clock-value ::= Minutes ":" Seconds ("." Fraction)?
	Timecount-value     ::= Timecount ("." Fraction)? (Metric)?


	Metric              ::= "h" | "min" | "s" | "ms"
	Hours               ::= DIGIT+; any positive number
	Minutes             ::= 2DIGIT; range from 00 to 59
	Seconds             ::= 2DIGIT; range from 00 to 59

	Fraction            ::= DIGIT+
	Timecount           ::= DIGIT+
	2DIGIT              ::= DIGIT DIGIT
	DIGIT               ::= [0-9] */

	digit = '\\d';
	ddigit = digit + digit;
	time = '(' + digit + '+' + ')';
	fraction = digit + '+';
	seconds = '(' + ddigit + ')'; // range from 00 to 59
	minutes = '(' + ddigit + ')'; // range from 00 to 59
	hours = '(' + digit + '+' + ')';
	metric = '(h|min|s|ms)';

	timecount = time + '(\\.' + fraction + ')?' + metric + '?';
	partialclock = minutes + ":"  + seconds + '(\\.' + fraction + ')?';
	fullclock = hours + ":" + minutes + ":" + seconds + '(\\.' + fraction + ')?';

	clock = '(' + fullclock + '|' + partialclock + '|' + timecount + ')';

	var re1 = new RegExp('^' + timecount + '$');
	var re2 = new RegExp('^' + partialclock + '$');
	var re3 = new RegExp('^' + fullclock + '$');

	var t = 0; // [s]

	       if ((arr = value.match(re1)) != null) {
		//alert('bingo! - 1');
		//alert(arr + '#' + arr.length + '#' + timecount);
		t = Number(arr[1] + arr[2]);
	} else if ((arr = value.match(re2)) != null) {
		//alert('bingo! - 2');
	} else if ((arr = value.match(re3)) != null) {
		//alert('bingo! - 3');
	} else {
		alert('invalid clock type');
	}


	return t;
}
